IF OBJECT_ID('[DashboardPackages_Latest]') IS NOT NULL DROP VIEW [DashboardPackages_Latest]
GO

CREATE VIEW [DashboardPackages_Latest]
AS
	SELECT * FROM
	(SELECT TOP 10 NP.[Feed_Id],
	              F.[Feed_Name],
				  NP.[Package_Id],
				  NPV.[Version_Text],
				  NPV.[Published_Date],
				  F.[FeedType_Name],
            [Group_Id] = NULL
	  FROM [NuGetPackageVersionsV2] NPV
	       INNER JOIN [NuGetPackagesV2] NP
		           ON NP.[NuGetPackageV2_Id] = NPV.[NuGetPackageV2_Id]
	       INNER JOIN [Feeds] F
		           ON F.[Feed_Id] = NP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND NPV.[Cached_Indicator] = 'N'
	 ORDER BY NPV.[Published_Date] DESC) A

	UNION ALL
	SELECT * FROM

	(SELECT TOP 10 NP.[Feed_Id],
	              F.[Feed_Name],
				  [Package_Id] = CASE WHEN NP.[Scope_Name] = '' THEN NP.[Package_Name] ELSE '@' + NP.[Scope_Name] + '/' + NP.[Package_Name] END,
				  NPV.[Version_Text],
				  NPV.[Published_Date],
				  F.[FeedType_Name],
            [Group_Id] = NULL
		  FROM [NpmPackageVersions] NPV
		       INNER JOIN [NpmPackages] NP
			           ON NP.[Package_Id] = NPV.[Package_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = NP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
       AND NPV.[Cached_Indicator] = 'N'
	 ORDER BY NPV.[Published_Date] DESC) B


	UNION ALL
	SELECT * FROM

	(SELECT TOP 10 MA.[Feed_Id],
	              F.[Feed_Name],
				  [Package_Id] = MA.[ArtifactId_Text],
				  MAF.[Version_Text],
				  MAF.[Updated_Date],
				  F.[FeedType_Name],
            [Group_Id] = MA.[GroupId_Text]
		  FROM [MavenArtifacts] MA
		       INNER JOIN [MavenArtifactFiles] MAF
			           ON MAF.[MavenArtifact_Id] = MA.[MavenArtifact_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = MA.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND MAF.[File_Type] = '.pom'
       AND MAF.[Cached_Indicator] = 'N'
	 ORDER BY MAF.[Updated_Date] DESC) C

	UNION ALL
	SELECT * FROM

	(SELECT TOP 10 F.[Feed_Id],
	              F.[Feed_Name],
				  [Package_Id] = PGP.[Package_Name],
				  PGPV.[Version_Text],
				  PGPV.[Published_Date],
				  F.[FeedType_Name],
            [Group_Id] = PGP.[Group_Name]
		  FROM [ProGetPackageVersions] PGPV
		       INNER JOIN [ProGetPackages] PGP
			           ON PGP.[ProGetPackage_Id] = PGPV.[ProGetPackage_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = PGP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
       AND PGPV.[Cached_Indicator] = 'N'
	 ORDER BY PGPV.[Published_Date] DESC) D

	UNION ALL
	SELECT * FROM

	(SELECT TOP 10 F.[Feed_Id],
	              F.[Feed_Name],
				  [Package_Id] = DR.[Repository_Name],
				  [Version_Text] = DRT.[Tag_Name],
				  DI.[Published_Date],
				  F.[FeedType_Name],
            [Group_Id] = NULL
		  FROM [DockerImages] DI
		       INNER JOIN [DockerRepositories] DR
			           ON DR.[DockerRepository_Id] = DI.[DockerRepository_Id]
		       INNER JOIN [DockerRepositoryTags] DRT
			           ON DRT.[DockerImage_Id] = DI.[DockerImage_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = DR.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	 ORDER BY DI.[Published_Date] DESC) E

	UNION ALL
	SELECT * FROM

	(SELECT TOP 10 F.[Feed_Id],
	              F.[Feed_Name],
				  [Package_Id] = RG.[Gem_Name],
				  RGV.[Version_Text],
				  RGV.[Published_Date],
				  F.[FeedType_Name],
            [Group_Id] = NULL
		  FROM [RubyGemVersions] RGV
		       INNER JOIN [RubyGems] RG
			           ON RG.[Gem_Id] = RGV.[Gem_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = RG.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
       AND RGV.[Cached_Indicator] = 'N'
	 ORDER BY RGV.[Published_Date] DESC) E

	UNION ALL
	SELECT * FROM
	(SELECT TOP 10 VP.[Feed_Id],
	              F.[Feed_Name],
				  VP.[Package_Id],
				  [Version_Text] = CAST(VP.[Major_Number] AS VARCHAR(50)) + '.' + CAST(VP.[Minor_Number] AS VARCHAR(50)) + '.' + CAST(VP.[Build_Number] AS VARCHAR(50)) + '.' + CAST(VP.[Revision_Number] AS VARCHAR(50)),
				  VP.[Published_Date],
				  F.[FeedType_Name],
            [Group_Id] = NULL
	  FROM [VsixPackages] VP
	       INNER JOIN [Feeds] F
		           ON F.[Feed_Id] = VP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND VP.[Cached_Indicator] = 'N'
	 ORDER BY VP.[Published_Date] DESC) F

	UNION ALL
	SELECT * FROM
	(SELECT TOP 10 DP.[Feed_Id],
	              F.[Feed_Name],
				  [Package_Id] = DP.[Package_Name] + ':' + DP.[Architecture_Name],
				  DP.[Version_Text],
				  DP.[Published_Date],
				  F.[FeedType_Name],
				  [Group_Id] = DP.[Component_Name]
	  FROM [DebianPackages] DP
	       INNER JOIN [Feeds] F
		           ON F.[Feed_Id] = DP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND DP.[Cached_Indicator] = 'N'
	 ORDER BY DP.[Published_Date] DESC) G

 	UNION ALL
	SELECT * FROM
	(SELECT TOP 10 PP.[Feed_Id],
	              F.[Feed_Name],
				  [Package_Id] = PP.[Package_Name],
				  PP.[Version_Text],
				  PP.[Published_Date],
				  F.[FeedType_Name],
				  [Group_Id] = NULL
	  FROM [PypiPackages] PP
	       INNER JOIN [Feeds] F
		           ON F.[Feed_Id] = PP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND PP.[Cached_Indicator] = 'N'
	 ORDER BY PP.[Published_Date] DESC) H

	UNION ALL
	SELECT * FROM
	(SELECT TOP 10 HC.[Feed_Id],
	               F.[Feed_Name],
	               [Package_Id] = HC.[Chart_Name],
	               HC.[Version_Text],
	               HC.[Published_Date],
	               F.[FeedType_Name],
	               [Group_Id] = NULL
	  FROM [HelmCharts] HC
	       INNER JOIN [Feeds] F
	               ON F.[Feed_Id] = HC.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND HC.[Cached_Indicator] = 'N'
	 ORDER BY HC.[Published_Date] DESC) F

 	UNION ALL
	SELECT * FROM

	(SELECT TOP 10 F.[Feed_Id],
	              F.[Feed_Name],
				  [Package_Id] = RP.[Package_Name] COLLATE Latin1_General_CS_AS,
				  RPV.[FullVersion_Text],
				  RPV.[Published_Date],
				  F.[FeedType_Name],
            [Group_Id] = NULL
		  FROM [RpmPackageVersions] RPV
		       INNER JOIN [RpmPackages] RP
			           ON RP.[RpmPackage_Id] = RPV.[RpmPackage_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = RP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	 ORDER BY RPV.[Published_Date] DESC) E

GO