EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Licenses_UpdateLicense',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ NULL,
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Overwrites license title and URLs.'
GO

IF OBJECT_ID('[Licenses_UpdateLicense]') IS NOT NULL DROP PROCEDURE [Licenses_UpdateLicense]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Licenses_UpdateLicense]
(
	@External_Id VARCHAR(50),
	@Title_Text NVARCHAR(200),
	@LicenseUrls_Csv VARCHAR(MAX)
) AS
BEGIN

SET NOCOUNT ON

BEGIN TRY

	DECLARE @License_Id INT
	SET @License_Id = (SELECT [License_Id]
	                     FROM [Licenses]
	                     WITH (UPDLOCK)
	                    WHERE [External_Id] = @External_Id)

	IF @License_Id IS NULL
	BEGIN

		INSERT INTO [Licenses]
		(
			[External_Id],
			[Title_Text]
		)
		VALUES
		(
			@External_Id,
			@Title_Text
		)

		SET @License_Id = SCOPE_IDENTITY()

	END
	ELSE
	BEGIN

		UPDATE [Licenses]
		   SET [Title_Text] = @Title_Text
		 WHERE [License_Id] = @License_Id

	END

	DELETE FROM [LicenseUrls]
	 WHERE [License_Id] = @License_Id
	   AND [License_Url] NOT IN (SELECT [Value_Text] FROM dbo.CsvToTable(@LicenseUrls_Csv, ','))

	INSERT INTO [LicenseUrls]
	(
		[License_Id],
		[License_Url]
	)
	SELECT @License_Id,
	       U.[Value_Text]
	  FROM dbo.CsvToTable(@LicenseUrls_Csv, ',') U
	 WHERE NOT EXISTS(SELECT * FROM [LicenseUrls] WHERE [License_Url] = U.[Value_Text])

END TRY BEGIN CATCH
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Licenses_UpdateLicense] TO [ProGetUser_Role]